﻿local NekoLoot = LibStub("AceAddon-3.0"):GetAddon("NekoLoot")
local L = LibStub("AceLocale-3.0"):GetLocale("NekoLoot")

local FreeSlots = GetContainerNumFreeSlots

local lootMode = nil
local errorDialog = nil

function NekoLoot:ChangeLooting(mode, enable)
	NekoLoot:UnregisterEvent("LOOT_OPENED")
	local text = ""
	-- mode fast und enable, dann fast
	if mode == "fast" and enable then mode, text = "FastLootOpen", "Fast"
	
	-- mode extraFast und enable, dann extraFast und UI_ERROR Handling an
	elseif mode == "extraFast" and enable then
		mode, text = "ExtraFastLootOpen", "ExtraFast"
		NekoLoot:RegisterEvent("UI_ERROR_MESSAGE", "LootOpenOnError")
	
	-- mode extraFast und disable, dann Normal und UI_ERROR Handling aus
	elseif mode == "extraFast" and not enable then
		mode, text = "NormalLootOpen", "Normal"
		NekoLoot:UnregisterEvent("UI_ERROR_MESSAGE", "LootOpenOnError")
	
	-- mode nicht gesetzt oder modus deaktivieren, dann normal
	else mode, text = "NormalLootOpen", "Normal"
	end
	
	-- report changing to user
	if mode ~= self.lootMode and not (self.lootMode == nil and mode == "NormalLootOpen") then
		NekoLoot:Print(L["LootingChanged"] .. text)
	end
	
	-- store mode to check if changed later
	self.lootMode = mode

	-- finaly register loot mode to event - fired when a corpse is looted 
	NekoLoot:RegisterEvent("LOOT_OPENED", mode)
end

-- simple show lootframe
function NekoLoot:NormalLootOpen()
	NekoLoot:Update()
end

-- check if lootframe is needed
function NekoLoot:FastLootOpen()
	local empty, num = 0, GetNumLootItems()
	local modified = IsModifiedClick(AUTOLOOTTOGGLE)
	local default = GetCVar("autoLootDefault") == "1"
	-- autoloot
	-- versuche schneller zu looten
	if (modified or default) and not (modified and default) then
		for index = 1, NUM_BAG_SLOTS do
			empty = empty + FreeSlots(index)
		end
		
		if num <= empty then CloseLoot()
		else self:Update()
		end
	-- no autoloot
	elseif num > 0 then
		self:Update()
		if not self.lootFrame:IsShown() and IsFishingLoot() then
			PlaySound("FISHING REEL IN")
		end
	else
		CloseLoot()
	end
end

-- only close loot frame to speed up auto loot
function NekoLoot:ExtraFastLootOpen()
	CloseLoot();
end

local function ErrorDialogButtonHandler()
	if NekoLoot.dialog:IsShown() then
		NekoLoot.dialog:Hide()
		NekoLoot:ChangeLooting("extraFast", false)
		NekoLoot.db.profile.lootMode.extraFast = false
	end
end

-- check given event for inventory is full msg and if create error dialog
-- event			: event to handle
-- msg				: msg of event
function NekoLoot:LootOpenOnError(event, msg, ...)
	if msg == ERR_INV_FULL then
		UIErrorsFrame:Clear()
		-- NekoLoot:Print(RED_FONT_COLOR_CODE.."Inventar voll! Disable ExtraFastLooting or Cleanup your Bags..."..FONT_COLOR_CODE_CLOSE)
		NekoLoot:CreateDialog(
			"NekoLootErrorDialog",
			ERR_INV_FULL .. L["Error. Disable ExtraFastLooting"],
			"OK",
			"BOTTOM",
			ErrorDialogButtonHandler)
	end
end